===============
 Flask-Sitemap
===============

.. image:: https://img.shields.io/travis/inveniosoftware/flask-sitemap.svg
        :target: https://travis-ci.org/inveniosoftware/flask-sitemap

.. image:: https://img.shields.io/coveralls/inveniosoftware/flask-sitemap.svg
        :target: https://coveralls.io/r/inveniosoftware/flask-sitemap

.. image:: https://img.shields.io/github/tag/inveniosoftware/flask-sitemap.svg
        :target: https://github.com/inveniosoftware/flask-sitemap/releases

.. image:: https://img.shields.io/pypi/dm/flask-sitemap.svg
        :target: https://pypi.python.org/pypi/flask-sitemap

.. image:: https://img.shields.io/github/license/inveniosoftware/flask-sitemap.svg
        :target: https://github.com/inveniosoftware/flask-sitemap/blob/master/LICENSE


About
=====

Flask-Sitemap is a Flask extension helping with sitemap generation.

Installation
============

Flask-Sitemap is on PyPI so all you need is: ::

    pip install Flask-Sitemap

Documentation
=============

Documentation is readable at http://flask-sitemap.readthedocs.org or can
be built using Sphinx: ::

    git submodule init
    git submodule update
    pip install Sphinx
    python setup.py build_sphinx

Testing
=======

Running the test suite is as simple as: ::

    python setup.py test

or, to also show code coverage: ::

    ./run-tests.sh
